@@ -8,23 +8,18 @@ import {ResultCommand} from 'gmp/commands/results';
 import {createEntityResponse, createHttp} from 'gmp/commands/testing';
 
 describe('ResultCommand tests', () => {
-  test('should return single result', () => {
+  test('should return single result', async () => {
     const response = createEntityResponse('result', {_id: 'foo'});
     const fakeHttp = createHttp(response);
-
-    expect.hasAssertions();
-
     const cmd = new ResultCommand(fakeHttp);
-    return cmd.get({id: 'foo'}).then(resp => {
-      expect(fakeHttp.request).toHaveBeenCalledWith('get', {
-        args: {
-          cmd: 'get_result',
-          result_id: 'foo',
-        },
-      });
-
-      const {data} = resp;
-      expect(data.id).toEqual('foo');
+    const resp = await cmd.get({id: 'foo'});
+    expect(fakeHttp.request).toHaveBeenCalledWith('get', {
+      args: {
+        cmd: 'get_result',
+        result_id: 'foo',
+      },
     });
+    const {data} = resp;
+    expect(data.id).toEqual('foo');
   });
 });
