@@ -5,12 +5,9 @@
 
 import {describe, test, expect} from '@gsa/testing';
 import Audit, {
-  HOSTS_ORDERING_RANDOM,
-  HOSTS_ORDERING_REVERSE,
-  HOSTS_ORDERING_SEQUENTIAL,
   AUDIT_STATUS,
   USAGE_TYPE,
-  AuditStatus,
+  type AuditStatus,
 } from 'gmp/models/audit';
 import {testModel} from 'gmp/models/testing';
 import {parseDate, parseDuration} from 'gmp/parser';
@@ -29,7 +26,6 @@ describe('Audit model tests', () => {
     expect(audit.config).toBeUndefined();
     expect(audit.current_report).toBeUndefined();
     expect(audit.first_report).toBeUndefined();
-    expect(audit.hosts_ordering).toBeUndefined();
     expect(audit.in_assets).toBeUndefined();
     expect(audit.last_report).toBeUndefined();
     expect(audit.max_checks).toBeUndefined();
@@ -62,7 +58,6 @@ describe('Audit model tests', () => {
     expect(audit.config).toBeUndefined();
     expect(audit.current_report).toBeUndefined();
     expect(audit.first_report).toBeUndefined();
-    expect(audit.hosts_ordering).toBeUndefined();
     expect(audit.in_assets).toBeUndefined();
     expect(audit.last_report).toBeUndefined();
     expect(audit.max_checks).toBeUndefined();
@@ -84,23 +79,6 @@ describe('Audit model tests', () => {
     expect(audit.usageType).toEqual(USAGE_TYPE.audit);
   });
 
-  test('should parse hosts ordering', () => {
-    // @ts-expect-error
-    const audit = Audit.fromElement({hosts_ordering: 'foo'});
-    expect(audit.hosts_ordering).toBeUndefined();
-
-    const audit2 = Audit.fromElement({hosts_ordering: HOSTS_ORDERING_RANDOM});
-    expect(audit2.hosts_ordering).toEqual(HOSTS_ORDERING_RANDOM);
-
-    const audit3 = Audit.fromElement({hosts_ordering: HOSTS_ORDERING_REVERSE});
-    expect(audit3.hosts_ordering).toEqual(HOSTS_ORDERING_REVERSE);
-
-    const audit4 = Audit.fromElement({
-      hosts_ordering: HOSTS_ORDERING_SEQUENTIAL,
-    });
-    expect(audit4.hosts_ordering).toEqual(HOSTS_ORDERING_SEQUENTIAL);
-  });
-
   test('should parse last report', () => {
     const audit = Audit.fromElement({
       _id: 't1',
@@ -469,7 +447,7 @@ describe(`Audit Model methods tests`, () => {
       [AUDIT_STATUS.stopped]: false,
       [AUDIT_STATUS.new]: false,
       [AUDIT_STATUS.interrupted]: false,
-      [AUDIT_STATUS.container]: false,
+      [AUDIT_STATUS.import]: false,
       [AUDIT_STATUS.uploading]: false,
       [AUDIT_STATUS.done]: false,
       [AUDIT_STATUS.unknown]: false,
@@ -492,7 +470,7 @@ describe(`Audit Model methods tests`, () => {
       [AUDIT_STATUS.stopped]: false,
       [AUDIT_STATUS.new]: false,
       [AUDIT_STATUS.interrupted]: false,
-      [AUDIT_STATUS.container]: false,
+      [AUDIT_STATUS.import]: false,
       [AUDIT_STATUS.uploading]: false,
       [AUDIT_STATUS.done]: false,
       [AUDIT_STATUS.unknown]: false,
@@ -515,7 +493,7 @@ describe(`Audit Model methods tests`, () => {
       [AUDIT_STATUS.stopped]: true,
       [AUDIT_STATUS.new]: false,
       [AUDIT_STATUS.interrupted]: false,
-      [AUDIT_STATUS.container]: false,
+      [AUDIT_STATUS.import]: false,
       [AUDIT_STATUS.uploading]: false,
       [AUDIT_STATUS.done]: false,
       [AUDIT_STATUS.unknown]: false,
@@ -538,7 +516,7 @@ describe(`Audit Model methods tests`, () => {
       [AUDIT_STATUS.stopped]: false,
       [AUDIT_STATUS.new]: false,
       [AUDIT_STATUS.interrupted]: true,
-      [AUDIT_STATUS.container]: false,
+      [AUDIT_STATUS.import]: false,
       [AUDIT_STATUS.uploading]: false,
       [AUDIT_STATUS.done]: false,
       [AUDIT_STATUS.unknown]: false,
@@ -561,7 +539,7 @@ describe(`Audit Model methods tests`, () => {
       [AUDIT_STATUS.stopped]: false,
       [AUDIT_STATUS.new]: true,
       [AUDIT_STATUS.interrupted]: false,
-      [AUDIT_STATUS.container]: false,
+      [AUDIT_STATUS.import]: false,
       [AUDIT_STATUS.uploading]: false,
       [AUDIT_STATUS.done]: false,
       [AUDIT_STATUS.unknown]: false,
