@@ -3,7 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import Model, {ModelElement, ModelProperties} from 'gmp/models/model';
+import Model, {type ModelElement, type ModelProperties} from 'gmp/models/model';
 import {parseCsv} from 'gmp/parser';
 
 interface GroupElement extends ModelElement {
@@ -15,7 +15,7 @@ export interface GroupProperties extends ModelProperties {
 }
 
 class Group extends Model {
-  static entityType = 'group';
+  static readonly entityType = 'group';
 
   readonly users: string[];
 
