@@ -3,7 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import createDate, {Date as GmpDate, duration} from 'gmp/models/date';
+import createDate, {type Date as GmpDate, duration} from 'gmp/models/date';
 import {isDefined, isString, isNumber, isArray} from 'gmp/utils/identity';
 import {isEmpty} from 'gmp/utils/string';
 
@@ -116,8 +116,8 @@ export const parseIntoArray = <T>(value: T | Array<T>): Array<T> =>
 export const YES_VALUE = 1;
 export const NO_VALUE = 0;
 
-export const parseYesNo = (value?: string | number): YesNo =>
-  value === '1' || value === 1 ? YES_VALUE : NO_VALUE;
+export const parseYesNo = (value?: string | number | boolean): YesNo =>
+  value === true || value === '1' || value === 1 ? YES_VALUE : NO_VALUE;
 
 export const parseYes = (value: string): YesNo => {
   return value === 'yes' ? YES_VALUE : NO_VALUE;
