@@ -6,29 +6,21 @@
 import {describe, test, expect} from '@gsa/testing';
 import {screen, rendererWith} from 'web/testing';
 import {Route, Routes} from 'react-router';
-import Capabilities from 'gmp/capabilities/capabilities';
+import Features from 'gmp/capabilities/features';
 import ConditionalRoute from 'web/components/conditionalRoute/ConditionalRoute';
 
 const MockComponent = () => <div>Mock Component</div>;
 
 describe('ConditionalRoute', () => {
-  const featureList = [
-    {name: 'ENABLED_FEATURE', _enabled: 1},
-    {name: 'DISABLED_FEATURE', _enabled: 0},
-  ];
-  const capabilities = new Capabilities(['everything'], featureList);
-  const {render} = rendererWith({capabilities, router: true});
+  const featureList = ['ENABLED_FEATURE'];
+  const features = new Features(featureList);
+  const {render} = rendererWith({router: true, features});
   test.each([
     {
       feature: 'ENABLED_FEATURE',
       expectedText: 'Mock Component',
       description: 'renders the component when the feature is enabled',
     },
-    {
-      feature: 'DISABLED_FEATURE',
-      expectedText: 'Not Found',
-      description: 'redirects when the feature is disabled',
-    },
     {
       feature: 'unknown-feature',
       expectedText: 'Not Found',
