@@ -3,12 +3,11 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
 import React from 'react';
+import {isDefined} from 'gmp/utils/identity';
 import withFilterSelection from 'web/components/dashboard/display/withFilterSelection';
 import PropTypes from 'web/utils/PropTypes';
 
-
 const createDisplay = ({
   chartComponent: Chart,
   displayComponent: Display,
@@ -31,7 +30,7 @@ const createDisplay = ({
         >
           {isDefined(Chart)
             ? displayProps => <Chart {...displayProps} />
-            : undefined}
+            : null}
         </Display>
       )}
     </Loader>
