@@ -4,11 +4,11 @@
  */
 
 import React from 'react';
-import {AlertCircle} from 'lucide-react';
 import {isDefined} from 'gmp/utils/identity';
 import ErrorContainer from 'web/components/error/ErrorContainer';
+import {AlertCircleIcon} from 'web/components/icon';
 import Divider from 'web/components/layout/Divider';
-import Layout, {LayoutProps} from 'web/components/layout/Layout';
+import Layout, {type LayoutProps} from 'web/components/layout/Layout';
 import Theme from 'web/utils/Theme';
 
 interface ErrorMessageProps extends LayoutProps {
@@ -27,7 +27,7 @@ const ErrorMessage: React.FC<ErrorMessageProps> = ({
 }: ErrorMessageProps) => (
   <ErrorContainer data-testid={dataTestId}>
     <Divider grow align={['center', 'center']} flex="column" margin="20px">
-      <AlertCircle color={Theme.darkRed} size="24" />
+      <AlertCircleIcon color={Theme.darkRed} size="medium" />
       <Layout align={['center', 'center']} flex="column" {...props}>
         <b data-testid="error-message">{message}</b>
         <Divider grow align={['center', 'start']} flex="row" margin="20px">
