@@ -4,11 +4,12 @@
  */
 
 import {HelpIcon} from 'web/components/icon';
-import {ExtendedDynamicIconProps} from 'web/components/icon/createIconComponents';
-import ManualLink, {ManualLinkProps} from 'web/components/link/ManualLink';
+import {type ExtendedDynamicIconProps} from 'web/components/icon/createIconComponents';
+import ManualLink, {type ManualLinkProps} from 'web/components/link/ManualLink';
 
 interface ManualIconProps<TValue = string>
-  extends Pick<ManualLinkProps, 'anchor' | 'page' | 'searchTerm'>,
+  extends
+    Pick<ManualLinkProps, 'anchor' | 'page' | 'searchTerm'>,
     ExtendedDynamicIconProps<TValue> {}
 
 const ManualIcon = ({anchor, page, searchTerm, ...props}: ManualIconProps) => {
