@@ -4,25 +4,20 @@
  */
 
 import {describe, test, expect} from '@gsa/testing';
+import {render} from 'web/testing';
 import Img from 'web/components/img/Img';
-import {render} from 'web/utils/Testing';
-
 
 describe('Img tests', () => {
   test('should render', () => {
-    const {element} = render(
-      <Img alt="Greenbone Security Assistant" src="greenbone.svg" />,
-    );
+    const {element} = render(<Img alt="OPENVAS SCAN" src="greenbone.svg" />);
 
     expect(element).toMatchSnapshot();
   });
 
   test('should render img with attributes', () => {
-    const {element} = render(
-      <Img alt="Greenbone Security Assistant" src="greenbone.svg" />,
-    );
+    const {element} = render(<Img alt="OPENVAS SCAN" src="greenbone.svg" />);
 
-    expect(element).toHaveAttribute('alt', 'Greenbone Security Assistant');
+    expect(element).toHaveAttribute('alt', 'OPENVAS SCAN');
     expect(element).toHaveAttribute('src', '/img/greenbone.svg');
   });
 });
