@@ -6,9 +6,9 @@
 import React from 'react';
 import DialogNotification from 'web/components/notification/DialogNotification';
 import useDialogNotification, {
-  ErrorWithMessage,
+  type ErrorWithMessage,
 } from 'web/components/notification/useDialogNotification';
-import {updateDisplayName} from 'web/utils/displayName';
+import {updateDisplayName} from 'web/utils/display-name';
 
 export interface DialogNotificationProps {
   showError: (error: ErrorWithMessage) => void;
