@@ -4,9 +4,8 @@
  */
 
 import {describe, test, expect, testing} from '@gsa/testing';
+import {render, fireEvent} from 'web/testing';
 import Button from 'web/components/panel/Button';
-import {render, fireEvent} from 'web/utils/Testing';
-
 
 describe('InfoPanel button tests', () => {
   test('should render', () => {
