@@ -4,9 +4,8 @@
  */
 
 import {describe, test, expect, testing} from '@gsa/testing';
+import {render, screen, fireEvent, waitFor} from 'web/testing';
 import SearchBar from 'web/components/searchbar/SearchBar';
-import {render, screen, fireEvent, waitFor} from 'web/utils/Testing';
-
 
 describe('SearchBar', () => {
   const placeholder = 'Search...';
