@@ -6,21 +6,29 @@
 import React from 'react';
 import styled from 'styled-components';
 
-interface TableProps {
-  children: React.ReactNode;
+export interface TableProps extends React.TableHTMLAttributes<HTMLTableElement> {
+  children?: React.ReactNode;
   className?: string;
+  'data-testid'?: string;
   footer?: React.ReactNode;
   header?: React.ReactNode;
 }
 
-interface StyledTableProps {
+interface StyledTableProps extends TableProps {
   $fixed?: boolean;
   $size?: string;
 }
 
-const Table = ({children, className, footer, header}: TableProps) => {
+const Table = ({
+  children,
+  className,
+  footer,
+  header,
+  'data-testid': dataTestId,
+  ...other
+}: TableProps) => {
   return (
-    <table className={className}>
+    <table {...other} className={className} data-testid={dataTestId}>
       {header}
       {children}
       {footer}
