@@ -4,11 +4,11 @@
  */
 
 import {describe, test, expect} from '@gsa/testing';
-import TableBody from 'web/components/table/Body';
-import TableData from 'web/components/table/Data';
+import {render} from 'web/testing';
 import DetailsTable from 'web/components/table/DetailsTable';
-import TableRow from 'web/components/table/Row';
-import {render} from 'web/utils/Testing';
+import TableBody from 'web/components/table/TableBody';
+import TableData from 'web/components/table/TableData';
+import TableRow from 'web/components/table/TableRow';
 
 describe('DetailsTable tests', () => {
   test('should render', () => {
