@@ -6,45 +6,49 @@
 import React from 'react';
 import {showSuccessNotification} from '@greenbone/ui-lib';
 import {connect} from 'react-redux';
-import {Location} from 'react-router';
-import CollectionCounts from 'gmp/collection/CollectionCounts';
-import EntitiesCommand from 'gmp/commands/entities';
-import Gmp from 'gmp/gmp';
-import Rejection from 'gmp/http/rejection';
-import Response from 'gmp/http/response';
-import {XmlMeta, XmlResponseData} from 'gmp/http/transform/fastxml';
-import {TranslateOptions} from 'gmp/locale/lang';
+import {type Location} from 'react-router';
+import type CollectionCounts from 'gmp/collection/collection-counts';
+import type EntitiesCommand from 'gmp/commands/entities';
+import type Gmp from 'gmp/gmp';
+import type Rejection from 'gmp/http/rejection';
+import type Response from 'gmp/http/response';
+import {type XmlMeta} from 'gmp/http/transform/fast-xml';
+import {type TranslateOptions} from 'gmp/locale/lang';
 import logger from 'gmp/log';
-import Filter, {RESET_FILTER} from 'gmp/models/filter';
-import Model from 'gmp/models/model';
-import Tag from 'gmp/models/tag';
-import {YES_VALUE} from 'gmp/parser';
+import {type default as Filter, RESET_FILTER} from 'gmp/models/filter';
+import type Model from 'gmp/models/model';
+import type Tag from 'gmp/models/tag';
 import {map} from 'gmp/utils/array';
 import {
   getEntityType,
   apiType,
-  typeName,
   pluralizeType,
-} from 'gmp/utils/entitytype';
+  type EntityType,
+} from 'gmp/utils/entity-type';
 import {isDefined} from 'gmp/utils/identity';
-import TagsDialog, {TagsDialogData} from 'web/entities/TagsDialog';
-import actionFunction from 'web/entity/hooks/actionFunction';
-import TagDialog from 'web/pages/tags/Dialog';
+import {
+  type OnFilterChangedFunc,
+  type OnFilterCreatedFunc,
+} from 'web/components/powerfilter/useFilterDialogSave';
+import TagsDialog, {type TagsDialogData} from 'web/entities/TagsDialog';
+import actionFunction from 'web/entity/hooks/action-function';
+import {type OnDownloadedFunc} from 'web/entity/hooks/useEntityDownload';
+import TagDialog from 'web/pages/tags/TagDialog';
 import {createDeleteEntity} from 'web/store/entities/utils/actions';
 import {loadUserSettingDefaults} from 'web/store/usersettings/defaults/actions';
 import {getUserSettingsDefaults} from 'web/store/usersettings/defaults/selectors';
 import {getUsername} from 'web/store/usersettings/selectors';
 import compose from 'web/utils/Compose';
 import {generateFilename} from 'web/utils/Render';
-import SelectionType, {SelectionTypeType} from 'web/utils/SelectionType';
-import SortDirection, {SortDirectionType} from 'web/utils/SortDirection';
+import SelectionType, {type SelectionTypeType} from 'web/utils/SelectionType';
+import SortDirection, {type SortDirectionType} from 'web/utils/sort-direction';
 import {withRouter} from 'web/utils/withRouter';
 import withTranslation from 'web/utils/withTranslation';
 
 type NavigateFunction = (args: {pathname: string; search?: string}) => void;
 
 export interface EntitiesContainerRenderProps<TModel extends Model = Model> {
-  createFilterType: string;
+  createFilterType: EntityType;
   entities?: TModel[];
   entitiesCounts?: CollectionCounts;
   entitiesError?: Error | Rejection;
@@ -59,12 +63,12 @@ export interface EntitiesContainerRenderProps<TModel extends Model = Model> {
   onDelete: (entity: TModel) => Promise<void>;
   onDeleteBulk: () => Promise<void>;
   onDownloadBulk: () => Promise<void>;
-  onDownloaded: (data: {filename: string; data: string}) => void;
+  onDownloaded: OnDownloadedFunc;
   onEntitySelected: (entity: TModel) => void;
   onEntityDeselected: (entity: TModel) => void;
   onError: (error: Error | Rejection) => void;
-  onFilterChanged: (filter: Filter) => void;
-  onFilterCreated: (filter: Filter) => void;
+  onFilterChanged: OnFilterChangedFunc;
+  onFilterCreated: OnFilterCreatedFunc;
   onFilterRemoved: () => void;
   onFilterReset: () => void;
   onFirstClick: () => void;
@@ -100,7 +104,7 @@ interface EntitiesContainerProps<TModel extends Model = Model> {
   entitiesError?: Error | Rejection;
   filter: Filter;
   gmp: Gmp;
-  gmpName: string;
+  gmpName: EntityType;
   isLoading?: boolean;
   loadedFilter?: Filter;
   notify: (message: string) => () => void;
@@ -109,11 +113,12 @@ interface EntitiesContainerProps<TModel extends Model = Model> {
   showErrorMessage: (message: string) => void;
   showSuccessMessage: (message: string) => void;
   updateFilter: (filter?: Filter) => void;
-  onDownload: (data: {filename: string; data: string}) => void;
+  onDownload: OnDownloadedFunc;
 }
 
-interface EntitiesContainerPropsWithHOCs<TModel extends Model = Model>
-  extends EntitiesContainerProps<TModel> {
+interface EntitiesContainerPropsWithHOCs<
+  TModel extends Model = Model,
+> extends EntitiesContainerProps<TModel> {
   deleteEntity: (id: string) => Promise<void>;
   loadSettings: () => void;
   location: Location;
@@ -152,6 +157,12 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
 
     this.entitiesCommand = gmp[entitiesCommandName];
 
+    if (!isDefined(this.entitiesCommand)) {
+      throw new Error(
+        `EntitiesContainer: gmp.${entitiesCommandName} is not defined.`,
+      );
+    }
+
     this.notifyTimer = notify(`${entitiesCommandName}.timer`);
     this.notifyChanged = notify(`${entitiesCommandName}.changed`);
 
@@ -185,9 +196,9 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
     props: EntitiesContainerPropsWithHOCs,
     state: EntitiesContainerState,
   ) {
-    if (isDefined(props.entities)) {
+    if (isDefined(props.entities) || isDefined(props.entitiesError)) {
       // update only if new entities are available to avoid having no entities
-      // when the filter changes
+      // when the filter changes or when an error occurs during loading
       return {
         entities: props.entities,
         entitiesCounts: props.entitiesCounts,
@@ -270,7 +281,7 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
     const {entities = [], loadedFilter, selected, selectionType} = this.state;
     const {listExportFileName, username, onDownload} = this.props;
 
-    let promise: Promise<Response<XmlResponseData, XmlMeta>>;
+    let promise: Promise<Response<string>>;
 
     if (selectionType === SelectionType.SELECTION_USER) {
       promise = entitiesCommand.export(Array.from(selected as Set<TModel>));
@@ -290,7 +301,6 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
         username,
       });
       const {data} = response;
-      // @ts-expect-error
       onDownload({filename, data});
       showSuccessNotification('', _('Bulk download completed.'));
     } catch (error) {
@@ -438,30 +448,24 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
     const {gmp} = this.props;
     const {tags} = this.state;
 
-    return (
-      // @ts-expect-error
-      gmp.tag
-        .create(data)
-        // @ts-expect-error
-        .then(response => gmp.tag.get(response.data))
-        .then(response => {
-          this.closeTagDialog();
-          this.setState({
-            tag: response.data,
-            tags: [...tags, response.data],
-          });
-        })
-    );
+    return gmp.tag
+      .create(data)
+      .then(response => gmp.tag.get(response.data))
+      .then(response => {
+        this.closeTagDialog();
+        this.setState({
+          tag: response.data,
+          tags: [...tags, response.data],
+        });
+      });
   }
 
-  handleTagChange(id: string) {
+  async handleTagChange(id: string) {
     const {gmp} = this.props;
 
-    // @ts-expect-error
-    gmp.tag.get({id}).then(response => {
-      this.setState({
-        tag: response.data,
-      });
+    const response = await gmp.tag.get({id});
+    this.setState({
+      tag: response.data,
     });
   }
 
@@ -472,7 +476,7 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
     const entitiesType = getEntityType(entities[0]);
 
     let resourceIds: string[] | undefined;
-    let filter;
+    let filter: Filter | undefined;
     if (selectionType === SelectionType.SELECTION_USER) {
       resourceIds = map(selected, res => res.id as string);
       filter = undefined;
@@ -482,17 +486,16 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
       filter = (loadedFilter as Filter).all();
     }
 
-    // @ts-expect-error
     return gmp.tag
       .save({
-        active: YES_VALUE,
+        active: true,
         comment,
         filter,
-        id,
-        name,
-        resource_ids: resourceIds,
-        resource_type: entitiesType,
-        resources_action: 'add',
+        id: id as string,
+        name: name as string,
+        resourceIds,
+        resourceType: entitiesType,
+        resourcesAction: 'add',
         value,
       })
       .then(() => this.closeTagsDialog());
@@ -520,8 +523,7 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
 
     if (entities.length > 0) {
       const filter = 'resource_type=' + apiType(getEntityType(entities[0]));
-      // @ts-expect-error
-      gmp.tags.getAll({filter}).then(response => {
+      void gmp.tags.getAll({filter}).then(response => {
         const {data: tags} = response;
         this.setState({tags});
       });
@@ -567,14 +569,14 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
       showSuccessMessage,
     } = this.props;
 
-    let entitiesType: string | undefined;
-    let resourceTypes: [string, string][] | undefined;
+    let entitiesType: EntityType | undefined;
+    let resourceTypes: EntityType[] = [];
     if (isDefined(entities) && entities.length > 0) {
       entitiesType = getEntityType(entities[0]);
-      resourceTypes = [[entitiesType, typeName(entitiesType)]];
+      resourceTypes = [entitiesType];
     }
 
-    let title;
+    let title: string;
     if (selectionType === SelectionType.SELECTION_USER) {
       title = _('Add Tag to Selection');
     } else if (selectionType === SelectionType.SELECTION_PAGE_CONTENTS) {
@@ -593,9 +595,9 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
         : (loadedFilter.get('sort') as string);
     const sortDir = reverse ? SortDirection.DESC : SortDirection.ASC;
     return (
-      <React.Fragment>
+      <>
         {children({
-          createFilterType: apiType(this.props.gmpName) as string,
+          createFilterType: this.props.gmpName,
           entities,
           entitiesCounts,
           entitiesError,
@@ -646,14 +648,13 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
         {tagDialogVisible && (
           <TagDialog
             fixed={true}
-            resource_type={entitiesType}
-            resource_types={resourceTypes}
-            resources={selected}
+            resourceType={entitiesType}
+            resourceTypes={resourceTypes}
             onClose={this.handleCloseTagDialog}
             onSave={this.handleCreateTag}
           />
         )}
-      </React.Fragment>
+      </>
     );
   }
 }
