@@ -3,28 +3,32 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {getEntityType, typeName, EntityType} from 'gmp/utils/entitytype';
+import {
+  type EntityType,
+  getEntityType,
+  typeName,
+  type WithEntityType,
+} from 'gmp/utils/entity-type';
 import {isDefined} from 'gmp/utils/identity';
 import {CloneIcon} from 'web/components/icon';
-import {ExtendedDynamicIconProps} from 'web/components/icon/createIconComponents';
+import {type ExtendedDynamicIconProps} from 'web/components/icon/createIconComponents';
 import useCapabilities from 'web/hooks/useCapabilities';
 import useTranslation from 'web/hooks/useTranslation';
 
-interface EntityClone extends EntityType {
+interface EntityClone extends WithEntityType {
   userCapabilities: {
-    mayAccess: (name: string) => boolean;
+    mayAccess: (name: EntityType) => boolean;
   };
 }
 
-interface EntityCloneIconProps<TEntity extends EntityClone>
-  extends Omit<
-    ExtendedDynamicIconProps<TEntity>,
-    'onClick' | 'value' | 'active'
-  > {
+interface EntityCloneIconProps<TEntity extends EntityClone> extends Omit<
+  ExtendedDynamicIconProps<TEntity>,
+  'onClick' | 'value' | 'active'
+> {
   displayName?: string;
   entity: TEntity;
   mayClone?: boolean;
-  name?: string;
+  name?: EntityType;
   title?: string;
   onClick?: (value: TEntity) => void | Promise<void>;
 }
