@@ -14,9 +14,11 @@ interface PortListImportDialogProps {
 }
 
 interface PortListImportDialogValues {
-  xmlFile: File;
+  xmlFile?: File;
 }
 
+export type PortListImportDialogState = PortListImportDialogValues;
+
 const PortListImportDialog = ({onClose, onSave}: PortListImportDialogProps) => {
   const [_] = useTranslation();
   return (
@@ -26,10 +28,14 @@ const PortListImportDialog = ({onClose, onSave}: PortListImportDialogProps) => {
       onClose={onClose}
       onSave={onSave}
     >
-      {({onValueChange}) => {
+      {({values, onValueChange}) => {
         return (
           <FormGroup title={_('Import XML Port List')}>
-            <FileField name="xmlFile" onChange={onValueChange} />
+            <FileField
+              name="xmlFile"
+              value={values.xmlFile}
+              onChange={onValueChange}
+            />
           </FormGroup>
         );
       }}
