@@ -6,10 +6,9 @@
 import React from 'react';
 import {describe, test, expect, testing} from '@gsa/testing';
 import {screen, within, rendererWith, fireEvent} from 'web/testing';
-import Capabilities from 'gmp/capabilities/capabilities';
 import Filter from 'gmp/models/filter';
-import {currentSettingsDefaultResponse} from 'web/pages/__mocks__/CurrentSettings';
-import {getMockAuditDeltaReport} from 'web/pages/reports/__mocks__/MockAuditDeltaReport';
+import {currentSettingsDefaultResponse} from 'web/pages/__fixtures__/current-settings';
+import {getMockAuditDeltaReport} from 'web/pages/reports/__fixtures__/MockAuditDeltaReport';
 import DeltaDetailsContent from 'web/pages/reports/DeltaDetailsContent';
 import {setTimezone, setUsername} from 'web/store/usersettings/actions';
 
@@ -23,19 +22,30 @@ const filterWithName = Filter.fromElement({
   id: '123',
 });
 
-const caps = new Capabilities(['everything']);
-
 const manualUrl = 'test/';
 
-const currentSettings = testing
-  .fn()
-  .mockResolvedValue(currentSettingsDefaultResponse);
+const createGmp = ({
+  currentSettingsResponse = currentSettingsDefaultResponse,
+  getReportComposerDefaultsResponse = {foo: 'bar'},
+  reportResultsThreshold = 10,
+  currentSettings = testing.fn().mockResolvedValue(currentSettingsResponse),
+  getReportComposerDefaults = testing
+    .fn()
+    .mockResolvedValue(getReportComposerDefaultsResponse),
+} = {}) => {
+  return {
+    settings: {
+      manualUrl,
+      reportResultsThreshold,
+    },
+    user: {
+      currentSettings,
+      getReportComposerDefaults,
+    },
+  };
+};
 
-const getReportComposerDefaults = testing.fn().mockResolvedValue({
-  foo: 'bar',
-});
-
-describe('Audit Delta Report Details Content tests', () => {
+describe('AuditDeltaDetailsContent tests', () => {
   test('should render Audit Delta Report Details Content', () => {
     const onAddToAssetsClick = testing.fn();
     const onError = testing.fn();
@@ -47,7 +57,6 @@ describe('Audit Delta Report Details Content tests', () => {
     const onFilterRemoveSeverityClick = testing.fn();
     const onFilterResetClick = testing.fn();
     const onFilterRemoveClick = testing.fn();
-
     const onRemoveFromAssetsClick = testing.fn();
     const onReportDownloadClick = testing.fn();
     const showError = testing.fn();
@@ -57,7 +66,6 @@ describe('Audit Delta Report Details Content tests', () => {
     const onTagSuccess = testing.fn();
     const onTargetEditClick = testing.fn();
     const onTlsCertificateDownloadClick = testing.fn();
-
     const sorting = {
       errors: {sortField: 'error', sortReverse: true},
       hosts: {sortField: 'compliant', sortReverse: true},
@@ -65,19 +73,15 @@ describe('Audit Delta Report Details Content tests', () => {
       results: {sortField: 'compliant', sortReverse: true},
       tlscerts: {sortField: 'dn', sortReverse: true},
     };
-
     const {entity} = getMockAuditDeltaReport();
-
     const filters = [filterWithName];
-
-    const gmp = {
-      settings: {manualUrl, reportResultsThreshold: 10},
-      user: {currentSettings, getReportComposerDefaults},
-    };
+    const gmp = createGmp({
+      reportResultsThreshold: 10,
+    });
 
     const {render, store} = rendererWith({
       gmp,
-      capabilities: caps,
+      capabilities: true,
       router: true,
       store: true,
     });
@@ -85,7 +89,7 @@ describe('Audit Delta Report Details Content tests', () => {
     store.dispatch(setTimezone('CET'));
     store.dispatch(setUsername('admin'));
 
-    const {baseElement} = render(
+    render(
       <DeltaDetailsContent
         audit={true}
         entity={entity}
@@ -121,89 +125,119 @@ describe('Audit Delta Report Details Content tests', () => {
       />,
     );
 
-    const icons = baseElement.querySelectorAll('svg');
-    const links = baseElement.querySelectorAll('a');
-    const tableData = baseElement.querySelectorAll('td');
-    const powerFilter = within(screen.queryPowerFilter());
-    const inputs = powerFilter.queryTextInputs();
-    const bars = screen.getAllByTestId('progressbar-box');
+    // buttons
+    const helpIcon = screen.getByTitle('Help: Audit Reports');
+    expect(helpIcon.closest('a')).toHaveAttribute(
+      'href',
+      'test/en/compliance-and-special-scans.html#using-and-managing-audit-reports',
+    );
 
-    // Toolbar Icons
-    expect(icons.length).toEqual(15);
+    expect(screen.getByTitle('Audit Reports List')).toBeInTheDocument();
+    expect(screen.getByTestId('list-link-icon')).toHaveAttribute(
+      'href',
+      '/auditreports',
+    );
+
+    expect(screen.getByTitle(/^Add to Assets/)).toBeInTheDocument();
+    expect(screen.getByTitle(/^Remove from Assets/)).toBeInTheDocument();
+    const correspondingTask = screen.getByTitle(/^Corresponding Task/);
+    expect(correspondingTask).toHaveAttribute('href', '/task/314');
+    const correspondingResults = screen.getByTitle(/^Corresponding Results/);
+    expect(correspondingResults).toHaveAttribute(
+      'href',
+      '/results?filter=report_id%3D1234',
+    );
+    expect(screen.getByTitle(/^Corresponding Performance/)).toBeInTheDocument();
+    expect(screen.getByTitle(/^Download filtered Report/)).toBeInTheDocument();
 
     // Powerfilter
+    const powerFilter = within(screen.queryPowerFilter());
+    const inputs = powerFilter.queryTextInputs();
     expect(inputs[0]).toHaveAttribute('name', 'userFilterString');
+    const select = powerFilter.getByTitle('Loaded filter');
+    expect(select).toHaveValue('foo');
 
-    const input = powerFilter.getByTitle('Loaded filter');
-    expect(input).toHaveValue('foo');
+    expect(
+      screen.getByRole('heading', {name: /Report: Mon/}),
+    ).toHaveTextContent(
+      'Mon, Jun 3, 2019 1:00 PM Central European Summer TimeDone',
+    );
 
-    // Header
-    expect(baseElement).toHaveTextContent(
-      'Report:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
+    const entityInfo = within(screen.getByTestId('entity-info'));
+    expect(entityInfo.getByRole('row', {name: /^ID:/})).toHaveTextContent(
+      '1234',
     );
-    expect(bars[0]).toHaveAttribute('title', 'Done');
-    expect(bars[0]).toHaveTextContent('Done');
-    expect(baseElement).toHaveTextContent(
-      'Created:Sun, Jun 2, 2019 2:00 PM Central European Summer Time',
+    expect(entityInfo.getByRole('row', {name: /^Created:/})).toHaveTextContent(
+      'Sun, Jun 2, 2019 2:00 PM Central European Summer Time',
     );
-    expect(baseElement).toHaveTextContent(
-      'Modified:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
+    expect(entityInfo.getByRole('row', {name: /^Modified:/})).toHaveTextContent(
+      'Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
+    );
+    expect(entityInfo.getByRole('row', {name: /^Owner:/})).toHaveTextContent(
+      'admin',
     );
-    expect(baseElement).toHaveTextContent('Owner:admin');
 
     // Tabs
-    expect(baseElement).toHaveTextContent('Information');
-    expect(baseElement).toHaveTextContent('Results(2)');
-    expect(baseElement).toHaveTextContent('User Tags(0)');
+    expect(
+      screen.getByRole('tab', {name: /^information/i}),
+    ).toBeInTheDocument();
+    expect(screen.getByRole('tab', {name: /^results/i})).toBeInTheDocument();
+    expect(screen.getByRole('tab', {name: /^user tags/i})).toBeInTheDocument();
 
-    // Summary
-    expect(tableData[0]).toHaveTextContent('Task Name');
-    expect(links[6]).toHaveAttribute('href', '/task/314');
-    expect(tableData[1]).toHaveTextContent('foo');
+    const taskName = screen.getByRole('row', {name: /^Task Name/});
+    expect(taskName).toHaveTextContent('foo');
+    expect(within(taskName).getByRole('link')).toHaveAttribute(
+      'href',
+      '/audit/314',
+    );
+    expect(screen.getByRole('row', {name: /^Comment/})).toHaveTextContent(
+      'bar',
+    );
 
-    expect(tableData[2]).toHaveTextContent('Comment');
-    expect(tableData[3]).toHaveTextContent('bar');
-
-    expect(tableData[4]).toHaveTextContent('Report 1');
-    expect(links[7]).toHaveAttribute('href', '/auditreport/1234');
-    expect(tableData[5]).toHaveTextContent('1234');
-
-    expect(tableData[6]).toHaveTextContent('Scan Time Report 1');
-    expect(tableData[7]).toHaveTextContent(
+    const reportRow1 = screen.getByRole('row', {name: /^Report 1/});
+    expect(reportRow1).toHaveTextContent('1234');
+    expect(within(reportRow1).getByRole('link')).toHaveAttribute(
+      'href',
+      '/auditreport/1234',
+    );
+    expect(
+      screen.getByRole('row', {name: /^Scan Time Report 1/}),
+    ).toHaveTextContent(
       'Mon, Jun 3, 2019 1:00 PM Central European Summer Time - Mon, Jun 3, 2019 1:31 PM Central European Summer Time',
     );
+    expect(
+      screen.getByRole('row', {name: /^Scan Duration Report 1/}),
+    ).toHaveTextContent('0:31 h');
+    expect(
+      screen.getByRole('row', {name: /^Scan Status Report 1/}),
+    ).toHaveTextContent('Done');
 
-    expect(tableData[8]).toHaveTextContent('Scan Duration Report 1');
-    expect(tableData[9]).toHaveTextContent('0:31 h');
-
-    expect(tableData[10]).toHaveTextContent('Scan Status Report 1');
-    expect(bars[1]).toHaveTextContent('Done');
-
-    expect(tableData[12]).toHaveTextContent('Report 2');
-    expect(links[8]).toHaveAttribute('href', '/auditreport/5678');
-    expect(tableData[13]).toHaveTextContent('5678');
-
-    expect(tableData[14]).toHaveTextContent('Scan Time Report 2');
-    expect(tableData[15]).toHaveTextContent(
+    const reportRow2 = screen.getByRole('row', {name: /^Report 2/});
+    expect(reportRow2).toHaveTextContent('5678');
+    expect(within(reportRow2).getByRole('link')).toHaveAttribute(
+      'href',
+      '/auditreport/5678',
+    );
+    expect(
+      screen.getByRole('row', {name: /^Scan Time Report 2/}),
+    ).toHaveTextContent(
       'Mon, May 20, 2019 2:00 PM Central European Summer Time - Mon, May 20, 2019 2:30 PM Central European Summer Time',
     );
-
-    expect(tableData[16]).toHaveTextContent('Scan Duration Report 2');
-    expect(tableData[17]).toHaveTextContent('0:30 h');
-
-    expect(tableData[18]).toHaveTextContent('Scan Status Report 2');
-    expect(bars[2]).toHaveTextContent('Done');
-
-    expect(tableData[20]).toHaveTextContent('Hosts scanned');
-    expect(tableData[21]).toHaveTextContent('3');
-
-    expect(tableData[22]).toHaveTextContent('Filter');
-    expect(tableData[23]).toHaveTextContent(
+    expect(
+      screen.getByRole('row', {name: /^Scan Duration Report 2/}),
+    ).toHaveTextContent('0:30 h');
+    expect(
+      screen.getByRole('row', {name: /^Scan Status Report 2/}),
+    ).toHaveTextContent('Done');
+    expect(screen.getByRole('row', {name: /^Hosts scanned/})).toHaveTextContent(
+      '3',
+    );
+    expect(screen.getByRole('row', {name: /^Filter/})).toHaveTextContent(
       'apply_overrides=0 compliance_levels=ynui min_qod=70',
     );
-
-    expect(tableData[24]).toHaveTextContent('Timezone');
-    expect(tableData[25]).toHaveTextContent('UTC (UTC)');
+    expect(screen.getByRole('row', {name: /^Timezone/})).toHaveTextContent(
+      'UTC (UTC)',
+    );
   });
 
   test('should render results tab', () => {
@@ -217,7 +251,6 @@ describe('Audit Delta Report Details Content tests', () => {
     const onFilterRemoveSeverityClick = testing.fn();
     const onFilterResetClick = testing.fn();
     const onFilterRemoveClick = testing.fn();
-
     const onRemoveFromAssetsClick = testing.fn();
     const onReportDownloadClick = testing.fn();
     const showError = testing.fn();
@@ -227,7 +260,6 @@ describe('Audit Delta Report Details Content tests', () => {
     const onTagSuccess = testing.fn();
     const onTargetEditClick = testing.fn();
     const onTlsCertificateDownloadClick = testing.fn();
-
     const sorting = {
       apps: {sortField: 'severity', sortReverse: true},
       closedcves: {sortField: 'severity', sortReverse: true},
@@ -239,19 +271,12 @@ describe('Audit Delta Report Details Content tests', () => {
       results: {sortField: 'severity', sortReverse: true},
       tlscerts: {sortField: 'dn', sortReverse: true},
     };
-
     const {entity} = getMockAuditDeltaReport();
-
     const filters = [filterWithName];
-
-    const gmp = {
-      settings: {manualUrl, reportResultsThreshold: 10},
-      user: {currentSettings, getReportComposerDefaults},
-    };
-
+    const gmp = createGmp();
     const {render, store} = rendererWith({
       gmp,
-      capabilities: caps,
+      capabilities: true,
       router: true,
       store: true,
     });
@@ -259,7 +284,7 @@ describe('Audit Delta Report Details Content tests', () => {
     store.dispatch(setTimezone('CET'));
     store.dispatch(setUsername('admin'));
 
-    const {baseElement} = render(
+    render(
       <DeltaDetailsContent
         audit={true}
         entity={entity}
@@ -296,48 +321,8 @@ describe('Audit Delta Report Details Content tests', () => {
     const resultsTab = screen.getByRole('tab', {name: /Results/});
     fireEvent.click(resultsTab);
 
-    const icons = baseElement.querySelectorAll('svg');
-    const header = baseElement.querySelectorAll('th');
-    const rows = baseElement.querySelectorAll('tr');
-    const powerFilter = within(screen.queryPowerFilter());
-    const inputs = screen.queryTextInputs();
-
-    // PowerFilter
-    expect(inputs[0]).toHaveAttribute('name', 'userFilterString');
-
-    const input = powerFilter.getByTitle('Loaded filter');
-    expect(input).toHaveValue('--');
-
-    const bars = screen.getAllByTestId('progressbar-box');
-
-    // Toolbar Icons
-    expect(icons.length).toEqual(37);
-
-    // Powerfilter
-    expect(inputs[0]).toHaveAttribute('name', 'userFilterString');
-
-    // Header
-    expect(baseElement).toHaveTextContent(
-      'Report:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
-    );
-    expect(bars[0]).toHaveAttribute('title', 'Done');
-    expect(bars[0]).toHaveTextContent('Done');
-    expect(baseElement).toHaveTextContent(
-      'Created:Sun, Jun 2, 2019 2:00 PM Central European Summer Time',
-    );
-    expect(baseElement).toHaveTextContent(
-      'Modified:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
-    );
-    expect(baseElement).toHaveTextContent('Owner:admin');
-
-    // Tabs
-    expect(baseElement).toHaveTextContent('Information');
-    expect(baseElement).toHaveTextContent('Results(2)');
-    expect(baseElement).toHaveTextContent('User Tags(0)');
-
-    // Results
-
     // Headings
+    const header = screen.getAllByRole('columnheader');
     expect(header[0]).toHaveTextContent('Delta');
     expect(header[1]).toHaveTextContent('Vulnerability');
     expect(header[3]).toHaveTextContent('Compliant');
@@ -349,32 +334,24 @@ describe('Audit Delta Report Details Content tests', () => {
     expect(header[9]).toHaveTextContent('Name');
 
     // Row 1
-    expect(within(rows[2]).getByTestId('equal-icon')).toBeVisible();
-    expect(rows[2]).toHaveTextContent('Result 1');
-    expect(bars[1]).toHaveAttribute('title', 'Yes');
-    expect(bars[1]).toHaveTextContent('Yes');
-    expect(rows[2]).toHaveTextContent('80 %');
-    expect(rows[2]).toHaveTextContent('123.456.78.910');
-    expect(rows[2]).toHaveTextContent('80/tcp');
-    expect(rows[2]).toHaveTextContent(
-      'Mon, Jun 3, 2019 1:06 PM Central European Summer Time',
+    const row1 = screen.getByRole('row', {name: /Result 1/});
+    expect(within(row1).getByTestId('equal-icon')).toBeVisible();
+    expect(row1).toHaveTextContent(
+      'Yes80 %123.456.78.91080/tcpMon, Jun 3, 2019 1:06 PM Central European Summer Time',
     );
 
     // Row 2
-    expect(within(rows[3]).getByTestId('equal-icon')).toBeVisible();
-    expect(rows[3]).toHaveTextContent('Result 2');
-    expect(bars[2]).toHaveAttribute('title', 'Incomplete');
-    expect(bars[2]).toHaveTextContent('Incomplete');
-    expect(rows[3]).toHaveTextContent('70 %');
-    expect(rows[3]).toHaveTextContent('109.876.54.321');
-    expect(rows[3]).toHaveTextContent('80/tcp');
-    expect(rows[3]).toHaveTextContent(
-      'Mon, Jun 3, 2019 1:06 PM Central European Summer Time',
+    const row2 = screen.getByRole('row', {name: /Result 2/});
+    expect(within(row2).getByTestId('equal-icon')).toBeVisible();
+    expect(row2).toHaveTextContent(
+      'Incomplete70 %109.876.54.32180/tcpMon, Jun 3, 2019 1:06 PM Central European Summer Time',
     );
 
-    // Filter
-    expect(baseElement).toHaveTextContent(
-      '(Applied filter: apply_overrides=0 compliance_levels=ynui rows=10 min_qod=70 first=1 sort=compliant)',
-    );
+    // displayed Filter
+    expect(
+      screen.getByText(
+        '(Applied filter: apply_overrides=0 compliance_levels=ynui rows=10 min_qod=70 first=1 sort=compliant)',
+      ),
+    ).toBeInTheDocument();
   });
 });
