@@ -5,36 +5,48 @@
 
 import {describe, test, expect, testing} from '@gsa/testing';
 import {screen, within, rendererWith, fireEvent} from 'web/testing';
-import Capabilities from 'gmp/capabilities/capabilities';
 import Filter from 'gmp/models/filter';
 import {SEVERITY_RATING_CVSS_3} from 'gmp/utils/severity';
-import {getMockDeltaReport} from 'web/pages/reports/__mocks__/MockDeltaReport';
+import {getMockDeltaReport} from 'web/pages/reports/__fixtures__/MockDeltaReport';
 import DeltaDetailsContent from 'web/pages/reports/DeltaDetailsContent';
 import {setTimezone, setUsername} from 'web/store/usersettings/actions';
 
 const filter = Filter.fromString(
-  'apply_overrides=0 levels=hml rows=2 min_qod=70 first=1 sort-reverse=severity',
+  'apply_overrides=0 levels=chml rows=2 min_qod=70 first=1 sort-reverse=severity',
 );
 
 const filterWithName = Filter.fromElement({
-  term: 'apply_overrides=0 levels=hml rows=2 min_qod=70 first=1 sort-reverse=severity',
+  term: 'apply_overrides=0 levels=chml rows=2 min_qod=70 first=1 sort-reverse=severity',
   name: 'foo',
   id: '123',
 });
 
-const caps = new Capabilities(['everything']);
-
 const manualUrl = 'test/';
 
-const currentSettings = testing.fn().mockResolvedValue({
-  foo: 'bar',
-});
+const createGmp = ({
+  currentSettingsResponse = {foo: 'bar'},
+  getReportComposerDefaultsResponse = {foo: 'bar'},
+  reportResultsThreshold = 10,
+  severityRating = undefined,
+  currentSettings = testing.fn().mockResolvedValue(currentSettingsResponse),
+  getReportComposerDefaults = testing
+    .fn()
+    .mockResolvedValue(getReportComposerDefaultsResponse),
+} = {}) => {
+  return {
+    settings: {
+      manualUrl,
+      reportResultsThreshold,
+      severityRating,
+    },
+    user: {
+      currentSettings,
+      getReportComposerDefaults,
+    },
+  };
+};
 
-const getReportComposerDefaults = testing.fn().mockResolvedValue({
-  foo: 'bar',
-});
-
-describe('Delta Report Details Content tests', () => {
+describe('DeltaReportDetailsContent tests', () => {
   test('should render Delta Report Details Content', () => {
     const onAddToAssetsClick = testing.fn();
     const onError = testing.fn();
@@ -46,7 +58,6 @@ describe('Delta Report Details Content tests', () => {
     const onFilterRemoveSeverityClick = testing.fn();
     const onFilterResetClick = testing.fn();
     const onFilterRemoveClick = testing.fn();
-
     const onRemoveFromAssetsClick = testing.fn();
     const onReportDownloadClick = testing.fn();
     const showError = testing.fn();
@@ -68,19 +79,12 @@ describe('Delta Report Details Content tests', () => {
       results: {sortField: 'severity', sortReverse: true},
       tlscerts: {sortField: 'dn', sortReverse: true},
     };
-
     const {entity} = getMockDeltaReport();
-
     const filters = [filterWithName];
-
-    const gmp = {
-      settings: {manualUrl, reportResultsThreshold: 10},
-      user: {currentSettings, getReportComposerDefaults},
-    };
-
+    const gmp = createGmp();
     const {render, store} = rendererWith({
       gmp,
-      capabilities: caps,
+      capabilities: true,
       router: true,
       store: true,
     });
@@ -88,7 +92,7 @@ describe('Delta Report Details Content tests', () => {
     store.dispatch(setTimezone('CET'));
     store.dispatch(setUsername('admin'));
 
-    const {baseElement} = render(
+    render(
       <DeltaDetailsContent
         entity={entity}
         filter={filterWithName}
@@ -120,85 +124,128 @@ describe('Delta Report Details Content tests', () => {
       />,
     );
 
-    const links = baseElement.querySelectorAll('a');
-    const tableData = baseElement.querySelectorAll('td');
-    const bars = screen.getAllByTestId('progressbar-box');
     const powerFilter = within(screen.queryPowerFilter());
     const select = powerFilter.getByTestId('powerfilter-select');
     const inputs = powerFilter.queryTextInputs();
 
+    // buttons
+    const helpIcon = screen.getByTitle('Help: Reading Reports');
+    expect(helpIcon.closest('a')).toHaveAttribute(
+      'href',
+      'test/en/reports.html#reading-a-report',
+    );
+
+    expect(screen.getByTitle('Reports List')).toBeInTheDocument();
+    expect(screen.getByTestId('list-link-icon')).toHaveAttribute(
+      'href',
+      '/reports',
+    );
+
+    expect(screen.getByTitle(/^Add to Assets/)).toBeInTheDocument();
+    expect(screen.getByTitle(/^Remove from Assets/)).toBeInTheDocument();
+    const correspondingTask = screen.getByTitle(/^Corresponding Task/);
+    expect(correspondingTask).toHaveAttribute('href', '/task/314');
+    const correspondingResults = screen.getByTitle(/^Corresponding Results/);
+    expect(correspondingResults).toHaveAttribute(
+      'href',
+      '/results?filter=report_id%3D1234',
+    );
+    const correspondingVulnerabilities = screen.getByTitle(
+      /^Corresponding Vulnerabilities/,
+    );
+    expect(correspondingVulnerabilities).toHaveAttribute(
+      'href',
+      '/vulnerabilities?filter=report_id%3D1234',
+    );
+    expect(screen.getByTitle(/^Corresponding Performance/)).toBeInTheDocument();
+    expect(screen.getByTitle(/^Download filtered Report/)).toBeInTheDocument();
+
     // Powerfilter
     expect(inputs[0]).toHaveAttribute('name', 'userFilterString');
     expect(select).toHaveAttribute('title', 'Loaded filter');
     expect(select).toHaveValue('foo');
 
-    // Header
-    expect(baseElement).toHaveTextContent(
-      'Report:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
+    expect(
+      screen.getByRole('heading', {name: /Report: Mon/}),
+    ).toHaveTextContent(
+      'Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
     );
-    expect(bars[0]).toHaveAttribute('title', 'Done');
-    expect(bars[0]).toHaveTextContent('Done');
-    expect(baseElement).toHaveTextContent(
-      'Created:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
+    const entityInfo = within(screen.getByTestId('entity-info'));
+    expect(entityInfo.getByRole('row', {name: /^ID:/})).toHaveTextContent(
+      '91011',
     );
-    expect(baseElement).toHaveTextContent(
-      'Modified:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
+    expect(entityInfo.getByRole('row', {name: /^Created:/})).toHaveTextContent(
+      'Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
+    );
+    expect(entityInfo.getByRole('row', {name: /^Modified:/})).toHaveTextContent(
+      'Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
+    );
+    expect(entityInfo.getByRole('row', {name: /^Owner:/})).toHaveTextContent(
+      'admin',
     );
-    expect(baseElement).toHaveTextContent('Owner:admin');
 
     // Tabs
-    expect(baseElement).toHaveTextContent('Information');
-    expect(baseElement).toHaveTextContent('Results(2)');
-    expect(baseElement).toHaveTextContent('User Tags(0)');
+    expect(
+      screen.getByRole('tab', {name: /^information/i}),
+    ).toBeInTheDocument();
+    expect(screen.getByRole('tab', {name: /^results/i})).toBeInTheDocument();
+    expect(screen.getByRole('tab', {name: /^user tags/i})).toBeInTheDocument();
 
-    // Summary
-    expect(tableData[0]).toHaveTextContent('Task Name');
-    expect(links[7]).toHaveAttribute('href', '/task/314');
-    expect(tableData[1]).toHaveTextContent('foo');
+    const taskName = screen.getByRole('row', {name: /^Task Name/});
+    expect(taskName).toHaveTextContent('foo');
+    expect(within(taskName).getByRole('link')).toHaveAttribute(
+      'href',
+      '/task/314',
+    );
+    expect(screen.getByRole('row', {name: /^Comment/})).toHaveTextContent(
+      'bar',
+    );
 
-    expect(tableData[2]).toHaveTextContent('Comment');
-    expect(tableData[3]).toHaveTextContent('bar');
-
-    expect(tableData[4]).toHaveTextContent('Report 1');
-    expect(links[8]).toHaveAttribute('href', '/report/1234');
-    expect(tableData[5]).toHaveTextContent('1234');
-
-    expect(tableData[6]).toHaveTextContent('Scan Time Report 1');
-    expect(tableData[7]).toHaveTextContent(
+    const reportRow1 = screen.getByRole('row', {name: /^Report 1/});
+    expect(reportRow1).toHaveTextContent('11234');
+    expect(within(reportRow1).getByRole('link')).toHaveAttribute(
+      'href',
+      '/report/1234',
+    );
+    expect(
+      screen.getByRole('row', {name: /^Scan Time Report 1/}),
+    ).toHaveTextContent(
       'Mon, Jun 3, 2019 1:00 PM Central European Summer Time - Mon, Jun 3, 2019 1:31 PM Central European Summer Time',
     );
+    expect(
+      screen.getByRole('row', {name: /^Scan Duration Report 1/}),
+    ).toHaveTextContent('0:31 h');
+    expect(
+      screen.getByRole('row', {name: /^Scan Status Report 1/}),
+    ).toHaveTextContent('Done');
 
-    expect(tableData[8]).toHaveTextContent('Scan Duration Report 1');
-    expect(tableData[9]).toHaveTextContent('0:31 h');
-
-    expect(tableData[10]).toHaveTextContent('Scan Status Report 1');
-    expect(bars[1]).toHaveTextContent('Done');
-
-    expect(tableData[12]).toHaveTextContent('Report 2');
-    expect(links[9]).toHaveAttribute('href', '/report/5678');
-    expect(tableData[13]).toHaveTextContent('5678');
-
-    expect(tableData[14]).toHaveTextContent('Scan Time Report 2');
-    expect(tableData[15]).toHaveTextContent(
+    const reportRow2 = screen.getByRole('row', {name: /^Report 2/});
+    expect(reportRow2).toHaveTextContent('5678');
+    expect(within(reportRow2).getByRole('link')).toHaveAttribute(
+      'href',
+      '/report/5678',
+    );
+    expect(
+      screen.getByRole('row', {name: /^Scan Time Report 2/}),
+    ).toHaveTextContent(
       'Mon, May 20, 2019 2:00 PM Central European Summer Time - Mon, May 20, 2019 2:30 PM Central European Summer Time',
     );
+    expect(
+      screen.getByRole('row', {name: /^Scan Duration Report 2/}),
+    ).toHaveTextContent('0:30 h');
+    expect(
+      screen.getByRole('row', {name: /^Scan Status Report 2/}),
+    ).toHaveTextContent('Done');
 
-    expect(tableData[16]).toHaveTextContent('Scan Duration Report 2');
-    expect(tableData[17]).toHaveTextContent('0:30 h');
-
-    expect(tableData[18]).toHaveTextContent('Scan Status Report 2');
-    expect(bars[2]).toHaveTextContent('Done');
-
-    expect(tableData[20]).toHaveTextContent('Hosts scanned');
-    expect(tableData[21]).toHaveTextContent('2');
-
-    expect(tableData[22]).toHaveTextContent('Filter');
-    expect(tableData[23]).toHaveTextContent(
-      'apply_overrides=0 levels=hml min_qod=70',
+    expect(screen.getByRole('row', {name: /^Hosts scanned/})).toHaveTextContent(
+      '2',
+    );
+    expect(screen.getByRole('row', {name: /^Filter/})).toHaveTextContent(
+      'apply_overrides=0 levels=chml min_qod=70',
+    );
+    expect(screen.getByRole('row', {name: /^Timezone/})).toHaveTextContent(
+      'UTC (UTC)',
     );
-
-    expect(tableData[24]).toHaveTextContent('Timezone');
-    expect(tableData[25]).toHaveTextContent('UTC (UTC)');
   });
 
   test('should render results tab', () => {
@@ -212,7 +259,6 @@ describe('Delta Report Details Content tests', () => {
     const onFilterRemoveSeverityClick = testing.fn();
     const onFilterResetClick = testing.fn();
     const onFilterRemoveClick = testing.fn();
-
     const onRemoveFromAssetsClick = testing.fn();
     const onReportDownloadClick = testing.fn();
     const showError = testing.fn();
@@ -234,23 +280,12 @@ describe('Delta Report Details Content tests', () => {
       results: {sortField: 'severity', sortReverse: true},
       tlscerts: {sortField: 'dn', sortReverse: true},
     };
-
     const {entity} = getMockDeltaReport();
-
     const filters = [filterWithName];
-
-    const gmp = {
-      settings: {
-        manualUrl,
-        reportResultsThreshold: 10,
-        severityRating: SEVERITY_RATING_CVSS_3,
-      },
-      user: {currentSettings, getReportComposerDefaults},
-    };
-
+    const gmp = createGmp({severityRating: SEVERITY_RATING_CVSS_3});
     const {render, store} = rendererWith({
       gmp,
-      capabilities: caps,
+      capabilities: true,
       router: true,
       store: true,
     });
@@ -258,7 +293,7 @@ describe('Delta Report Details Content tests', () => {
     store.dispatch(setTimezone('CET'));
     store.dispatch(setUsername('admin'));
 
-    const {baseElement} = render(
+    render(
       <DeltaDetailsContent
         entity={entity}
         filter={filter}
@@ -293,40 +328,8 @@ describe('Delta Report Details Content tests', () => {
     const resultsTab = screen.getByRole('tab', {name: /Results/});
     fireEvent.click(resultsTab);
 
-    const header = baseElement.querySelectorAll('th');
-    const rows = baseElement.querySelectorAll('tr');
-    const bars = screen.getAllByTestId('progressbar-box');
-    const powerFilter = within(screen.queryPowerFilter());
-    const select = powerFilter.getByTestId('powerfilter-select');
-    const inputs = powerFilter.queryTextInputs();
-
-    // Powerfilter
-    expect(inputs[0]).toHaveAttribute('name', 'userFilterString');
-    expect(select).toHaveAttribute('title', 'Loaded filter');
-    expect(select).toHaveValue('--');
-
-    // Header
-    expect(baseElement).toHaveTextContent(
-      'Report:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
-    );
-    expect(bars[0]).toHaveAttribute('title', 'Done');
-    expect(bars[0]).toHaveTextContent('Done');
-    expect(baseElement).toHaveTextContent(
-      'Created:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
-    );
-    expect(baseElement).toHaveTextContent(
-      'Modified:Mon, Jun 3, 2019 1:00 PM Central European Summer Time',
-    );
-    expect(baseElement).toHaveTextContent('Owner:admin');
-
-    // Tabs
-    expect(baseElement).toHaveTextContent('Information');
-    expect(baseElement).toHaveTextContent('Results(2)');
-    expect(baseElement).toHaveTextContent('User Tags(0)');
-
-    // Results
-
     // Headings
+    const header = screen.getAllByRole('columnheader');
     expect(header[0]).toHaveTextContent('Delta');
     expect(header[1]).toHaveTextContent('Vulnerability');
     expect(header[3]).toHaveTextContent('Severity');
@@ -338,32 +341,24 @@ describe('Delta Report Details Content tests', () => {
     expect(header[9]).toHaveTextContent('Name');
 
     // Row 1
-    expect(within(rows[2]).getByTestId('equal-icon')).toBeVisible();
-    expect(rows[2]).toHaveTextContent('Result 1');
-    expect(bars[1]).toHaveAttribute('title', 'Critical');
-    expect(bars[1]).toHaveTextContent('10.0 (Critical)');
-    expect(rows[2]).toHaveTextContent('80 %');
-    expect(rows[2]).toHaveTextContent('123.456.78.910');
-    expect(rows[2]).toHaveTextContent('80/tcp');
-    expect(rows[2]).toHaveTextContent(
-      'Mon, Jun 3, 2019 1:06 PM Central European Summer Time',
+    const row1 = screen.getByRole('row', {name: /Result 1/});
+    expect(within(row1).getByTestId('equal-icon')).toBeVisible();
+    expect(row1).toHaveTextContent(
+      '10.0 (Critical)80 %123.456.78.91080/tcpMon, Jun 3, 2019 1:06 PM Central European Summer Time',
     );
 
     // Row 2
-    expect(within(rows[3]).getByTestId('equal-icon')).toBeVisible();
-    expect(rows[3]).toHaveTextContent('Result 2');
-    expect(bars[2]).toHaveAttribute('title', 'Medium');
-    expect(bars[2]).toHaveTextContent('5.0 (Medium)');
-    expect(rows[3]).toHaveTextContent('70 %');
-    expect(rows[3]).toHaveTextContent('109.876.54.321');
-    expect(rows[3]).toHaveTextContent('80/tcp');
-    expect(rows[3]).toHaveTextContent(
-      'Mon, Jun 3, 2019 1:06 PM Central European Summer Time',
+    const row2 = screen.getByRole('row', {name: /Result 2/});
+    expect(within(row2).getByTestId('equal-icon')).toBeVisible();
+    expect(row2).toHaveTextContent(
+      '5.0 (Medium)70 %109.876.54.32180/tcpMon, Jun 3, 2019 1:06 PM Central European Summer Time',
     );
 
-    // Filter
-    expect(baseElement).toHaveTextContent(
-      '(Applied filter: apply_overrides=0 levels=hml rows=2 min_qod=70 first=1 sort-reverse=severity)',
-    );
+    // displayed filter
+    expect(
+      screen.getByText(
+        '(Applied filter: apply_overrides=0 levels=chml rows=2 min_qod=70 first=1 sort-reverse=severity)',
+      ),
+    ).toBeInTheDocument();
   });
 });
