@@ -9,7 +9,7 @@ import Filter, {REPORTS_FILTER_FILTER} from 'gmp/models/filter';
 import FilterTerm from 'gmp/models/filter/filterterm';
 import {parseInt, parseFloat, parseDate} from 'gmp/parser';
 import {isDefined} from 'gmp/utils/identity';
-import LineChart from 'web/components/chart/Line';
+import LineChart from 'web/components/chart/base/Line';
 import createDisplay from 'web/components/dashboard/display/createDisplay';
 import DataDisplay from 'web/components/dashboard/display/DataDisplay';
 import DataTableDisplay from 'web/components/dashboard/display/DataTableDisplay';
@@ -18,7 +18,7 @@ import {registerDisplay} from 'web/components/dashboard/Registry';
 import {ReportsHighResultsLoader} from 'web/pages/reports/dashboard/Loaders';
 import PropTypes from 'web/utils/PropTypes';
 import Theme from 'web/utils/Theme';
-import {formattedUserSettingLongDate} from 'web/utils/userSettingTimeDateFormatters';
+import {formattedUserSettingLongDate} from 'web/utils/user-setting-time-date-formatters';
 
 const transformHighResults = (data = {}) => {
   const {groups = []} = data;
