@@ -7,8 +7,8 @@ import {describe, test, expect, testing} from '@gsa/testing';
 import {screen, rendererWith} from 'web/testing';
 import Filter from 'gmp/models/filter';
 import {SEVERITY_RATING_CVSS_3} from 'gmp/utils/severity';
-import {getMockAuditReport} from 'web/pages/reports/__mocks__/MockAuditReport';
-import {getMockReport} from 'web/pages/reports/__mocks__/MockReport';
+import {getMockAuditReport} from 'web/pages/reports/__fixtures__/MockAuditReport';
+import {getMockReport} from 'web/pages/reports/__fixtures__/MockReport';
 import OperatingSystemsTab from 'web/pages/reports/details/OperatingSystemsTab';
 import {setTimezone, setUsername} from 'web/store/usersettings/actions';
 
