@@ -6,7 +6,7 @@
 import {describe, test, expect, testing} from '@gsa/testing';
 import {rendererWith, fireEvent} from 'web/testing';
 import Filter from 'gmp/models/filter';
-import {getMockReport} from 'web/pages/reports/__mocks__/MockReport';
+import {getMockReport} from 'web/pages/reports/__fixtures__/MockReport';
 import TLSCertificatesTab from 'web/pages/reports/details/TlsCertificatesTab';
 import {setTimezone, setUsername} from 'web/store/usersettings/actions';
 
