@@ -9,7 +9,7 @@ import Filter, {TLS_CERTIFICATES_FILTER_FILTER} from 'gmp/models/filter';
 import FilterTerm from 'gmp/models/filter/filterterm';
 import {parseInt, parseDate} from 'gmp/parser';
 import {isDefined} from 'gmp/utils/identity';
-import LineChart, {lineDataPropType} from 'web/components/chart/Line';
+import LineChart, {lineDataPropType} from 'web/components/chart/base/Line';
 import createDisplay from 'web/components/dashboard/display/createDisplay';
 import DataDisplay from 'web/components/dashboard/display/DataDisplay';
 import DataTableDisplay from 'web/components/dashboard/display/DataTableDisplay';
@@ -19,7 +19,7 @@ import {registerDisplay} from 'web/components/dashboard/Registry';
 import {TlsCertificatesModifiedLoader} from 'web/pages/tlscertificates/dashboard/Loaders';
 import PropTypes from 'web/utils/PropTypes';
 import Theme from 'web/utils/Theme';
-import {formattedUserSettingShortDate} from 'web/utils/userSettingTimeDateFormatters';
+import {formattedUserSettingShortDate} from 'web/utils/user-setting-time-date-formatters';
 
 const transformModified = (data = {}) => {
   const {groups = []} = data;
