@@ -7,16 +7,17 @@ import {
   USER_SETTINGS_DEFAULTS_LOADING_ERROR,
   USER_SETTINGS_DEFAULTS_LOADING_REQUEST,
   USER_SETTINGS_DEFAULTS_LOADING_SUCCESS,
+  USER_SETTINGS_DEFAULTS_OPTIMISTIC_UPDATE,
 } from 'web/store/usersettings/defaults/actions';
 import {combineReducers} from 'web/store/utils';
 
-
 const isLoading = (state = false, action) => {
   switch (action.type) {
     case USER_SETTINGS_DEFAULTS_LOADING_REQUEST:
       return true;
     case USER_SETTINGS_DEFAULTS_LOADING_ERROR:
     case USER_SETTINGS_DEFAULTS_LOADING_SUCCESS:
+    case USER_SETTINGS_DEFAULTS_OPTIMISTIC_UPDATE:
       return false;
     default:
       return state;
@@ -28,6 +29,7 @@ const error = (state, action) => {
     case USER_SETTINGS_DEFAULTS_LOADING_ERROR:
       return action.error;
     case USER_SETTINGS_DEFAULTS_LOADING_SUCCESS:
+    case USER_SETTINGS_DEFAULTS_OPTIMISTIC_UPDATE:
       return undefined;
     default:
       return state;
@@ -40,6 +42,22 @@ const byName = (state = {}, action) => {
       const {data} = action;
       return {...state, ...data};
     }
+    case USER_SETTINGS_DEFAULTS_OPTIMISTIC_UPDATE: {
+      const {name, value} = action;
+
+      const existingSetting = state[name] ? state[name] : {};
+
+      const updateSetting = {
+        ...existingSetting,
+        value,
+      };
+
+      return {
+        ...state,
+        [name]: updateSetting,
+      };
+    }
+
     default:
       return state;
   }
