@@ -7,12 +7,17 @@ import React from 'react';
 import {format} from 'd3-format';
 import {getFormattedDate} from 'gmp/locale/date';
 import {_} from 'gmp/locale/lang';
-import date, {Date} from 'gmp/models/date';
-import {parseBoolean, YesNo} from 'gmp/parser';
-import {typeName, getEntityType, EntityType} from 'gmp/utils/entitytype';
+import date, {type Date} from 'gmp/models/date';
+import {parseBoolean, type YesNo} from 'gmp/parser';
+import {
+  typeName,
+  getEntityType,
+  type WithEntityType,
+  type ApiType,
+} from 'gmp/utils/entity-type';
 import {isDefined, isFunction, isObject} from 'gmp/utils/identity';
 import {isEmpty, shorten, split} from 'gmp/utils/string';
-import {SelectItem} from 'web/components/form/Select';
+import {type SelectItem} from 'web/components/form/Select';
 
 export interface RenderSelectItemProps {
   name: string;
@@ -20,8 +25,20 @@ export interface RenderSelectItemProps {
   deprecated?: boolean | YesNo;
 }
 
-interface Resource extends EntityType {
-  name: string;
+export interface Resource extends WithEntityType {
+  name?: string;
+}
+
+export interface GenerateFilenameParams {
+  creationTime?: Date;
+  extension?: string;
+  fileNameFormat?: string;
+  reportFormat?: string;
+  id?: string;
+  modificationTime?: Date;
+  resourceName?: string;
+  resourceType?: string;
+  username?: string;
 }
 
 export const UNSET_VALUE = '0';
@@ -220,7 +237,11 @@ const getPermissionTypeName = (type: string) => {
   }
 };
 
-export const permissionDescription = (name, resource: Resource, subject) =>
+export const permissionDescription = (
+  name: string,
+  resource?: Resource,
+  subject?: Resource,
+) =>
   isDefined(subject)
     ? permissionDescriptionResourceWithSubject(name, resource, subject)
     : permissionDescriptionResource(name, resource);
@@ -233,7 +254,7 @@ export const permissionDescriptionResource = (
     name = name.toLowerCase();
     const resourceType = {
       type: typeName(getEntityType(resource))?.toLowerCase(),
-      name: resource.name,
+      name: resource.name as string,
     };
 
     if (name === 'super') {
@@ -270,9 +291,9 @@ export const permissionDescriptionResourceWithSubject = (
     name = name.toLowerCase();
     const type = {
       subjectType: typeName(getEntityType(subject)),
-      subjectName: subject.name,
+      subjectName: subject.name as string,
       resourceType: typeName(getEntityType(resource)),
-      resourceName: resource.name,
+      resourceName: resource.name as string,
     };
 
     if (name === 'super') {
@@ -356,7 +377,9 @@ export const simplePermissionDescription = (name: string) => {
 
   const [commandType, res] = split(name, '_', 1);
   const entityType =
-    commandType === 'get' ? getPermissionTypeName(res) : typeName(res);
+    commandType === 'get'
+      ? getPermissionTypeName(res)
+      : typeName(res as ApiType);
 
   switch (commandType) {
     case 'create':
@@ -457,9 +480,11 @@ export const simplePermissionDescriptionWithSubject = (
   const [commandType, res] = split(name, '_', 1);
   type = {
     subjectType: typeName(getEntityType(subject)),
-    subjectName: subject.name,
+    subjectName: subject.name as string,
     resourceType:
-      commandType === 'get' ? getPermissionTypeName(res) : typeName(res),
+      commandType === 'get'
+        ? getPermissionTypeName(res)
+        : typeName(res as ApiType),
   };
   switch (commandType) {
     case 'create':
@@ -522,7 +547,7 @@ export const simplePermissionDescriptionWithSubject = (
 };
 
 export const setRef =
-  <TRef,>(...refs: React.Ref<TRef>[]) =>
+  <TRef,>(...refs: (React.Ref<TRef> | null | undefined)[]) =>
   (ref: TRef) => {
     for (const rf of refs) {
       if (isFunction(rf)) {
@@ -544,17 +569,7 @@ export const generateFilename = ({
   resourceName,
   resourceType,
   username,
-}: {
-  creationTime?: Date;
-  extension?: string;
-  fileNameFormat?: string;
-  reportFormat?: string;
-  id?: string;
-  modificationTime?: Date;
-  resourceName?: string;
-  resourceType?: string;
-  username?: string;
-}) => {
+}: GenerateFilenameParams) => {
   const currentTime = date();
   const cTime = isDefined(creationTime) ? creationTime : currentTime;
 
